==> ZenTaoPMS.16.5.php8.0.zip: zentaopms/module/company/lang/en.php <==
<?php
/**
 * The company module English file of ZenTaoPMS.
 *
 * @copyright   Copyright 2009-2015 青岛易软天创网络科技有限公司(QingDao Nature Easy Soft Network Technology Co,LTD, www.cnezsoft.com)
 * @license     ZPL (http://zpl.pub/page/zplv12.html)
 * @author      Chunsheng Wang <chunsheng@cnezsoft.com>
 * @package     company
 * @version     $Id: en.php 4714 2013-05-02 08:10:58Z chencongzhi520@gmail.com $
 * @link        http://www.zentao.net
 */
$lang->company->common   = 'Company';
$lang->company->index    = "Company Home";
$lang->company->create   = "Add Company";
$lang->company->edit     = "Edit Company";
$lang->company->view     = "Company Information";
$lang->company->browse   = "User List";
$lang->company->dynamic  = "Dynamics";
$lang->company->orgView  = 'View';

$lang->company->id       = 'ID';
$lang->company->name     = 'Company Name';
$lang->company->phone    = 'Phone';
$lang->company->fax      = 'Fax';
$lang->company->address  = 'Mailing Address';
$lang->company->zipcode  = 'Zip Code';
$lang->company->website  = 'Website';
$lang->company->backyard = 'Intranet';
$lang->company->guest    = 'Guest Login';
$lang->company->admins   = 'Administrator';
$lang->company->deleted  = 'Deleted';

$lang->company->product   = $lang->productCommon;
$lang->company->project   = 'Project';
$lang->company->execution = 'Execution';
$lang->company->user      = 'User';
$lang->company->empty     = 'No Dynamic';

$lang->company->guestOptions[0] = 'Deny';
$lang->company->guestOptions[1] = 'Allow';

$lang->company->order['date_desc'] = 'Descending';
$lang->company->order['date_asc']  = 'Ascending';

==> ZenTaoPMS.17.2.php8.0.zip: zentaopms/module/company/lang/en.php <==
<?php
/**
 * The company module English file of ZenTaoPMS.
 *
 * @copyright   Copyright 2009-2015 青岛易软天创网络科技有限公司(QingDao Nature Easy Soft Network Technology Co,LTD, www.cnezsoft.com)
 * @license     ZPL(http://zpl.pub/page/zplv12.html) or AGPL(https://www.gnu.org/licenses/agpl-3.0.en.html)
 * @author      Chunsheng Wang <chunsheng@cnezsoft.com>
 * @package     company
 * @version     $Id: en.php 4714 2013-05-02 08:10:58Z chencongzhi520@gmail.com $
 * @link        http://www.zentao.net
 */
$lang->company->common   = 'Company';
$lang->company->index    = "Company Home";
$lang->company->create   = "Add Company";
$lang->company->edit     = "Edit Company";
$lang->company->view     = "Company Information";
$lang->company->browse   = "User List";
$lang->company->dynamic  = "Dynamics";
$lang->company->orgView  = 'View';

$lang->company->id       = 'ID';
$lang->company->name     = 'Company Name';
$lang->company->phone    = 'Phone';
$lang->company->fax      = 'Fax';
$lang->company->address  = 'Mailing Address';
$lang->company->zipcode  = 'Zip Code';
$lang->company->website  = 'Website';
$lang->company->backyard = 'Intranet';
$lang->company->guest    = 'Guest Login';
$lang->company->admins   = 'Administrator';
$lang->company->deleted  = 'Deleted';

$lang->company->product   = $lang->productCommon;
$lang->company->project   = 'Project';
$lang->company->execution = $lang->executionCommon;
$lang->company->user      = 'User';
$lang->company->empty     = 'No Dynamic';

$lang->company->guestOptions[0] = 'Deny';
$lang->company->guestOptions[1] = 'Allow';

$lang->company->order['date_desc'] = 'Descending';
$lang->company->order['date_asc']  = 'Ascending';
